@@ -8,6 +8,8 @@
 #
 from .complete_all_tasks import complete_all_tasks
 from .acall import acall
+from .async_deinitable import AsyncDeinitable
+from .async_initable import AsyncInitable
 from .async_on_stop import AsyncOnStop
 from .async_on_start import AsyncOnStart
 from .await_dict_values import await_dict_values
