@@ -8,6 +8,7 @@
 #
 import asyncio
 import itertools
+import typing
 from logging import getLogger
 
 logger = getLogger(__name__)
@@ -23,6 +24,7 @@ class AsyncDeinitable:
     def wait_before_async_deinit_for(self, task: asyncio.Task) -> None:
         self._tasks_before_async_deinit.append(task)
 
+    @typing.final
     async def async_deinit(self) -> None:
         if self.async_deinit_scheduled__event.is_set():
             logger.warning(f"async_start called extra time on {self}")
@@ -38,6 +40,7 @@ class AsyncDeinitable:
         self.async_deinit_finished__event.set()
 
     async def _async_deinit(self) -> None:
+        """Если дефолтная деинициализация не подходит, то переопределите этот метод"""
         await self._async_deinit_attrs()
 
     async def _async_deinit_attrs(self) -> None:
